@@ -65,6 +65,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "food_court", I18N_NOOP2("OSM::amenity/shop", "Food Court") },
     { "fountain", I18N_NOOP2("OSM::amenity/shop", "Fountain") },
     { "furniture", I18N_NOOP2("OSM::amenity/shop", "Furniture") },
+    { "gallery", I18N_NOOP2("OSM::amenity/shop", "Gallery") },
     { "garden_centre", I18N_NOOP2("OSM::amenity/shop", "Garden Center") },
     { "gift", I18N_NOOP2("OSM::amenity/shop", "Gift Shop") },
     { "greengrocer", I18N_NOOP2("OSM::amenity/shop", "Greengrocer") },
@@ -93,6 +94,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "mobile_phone", I18N_NOOP2("OSM::amenity/shop", "Mobile Phone") },
     { "money_transfer", I18N_NOOP2("OSM::amenity/shop", "Money Transfer") },
     { "motorcycle_parking", I18N_NOOP2("OSM::amenity/shop", "Motorcycle Parking") },
+    { "motorcycle_rental", I18N_NOOP2("OSM::amenity/shop", "Motorcycle Rental") },
     { "museum", I18N_NOOP2("OSM::amenity/shop", "Museum") },
     { "music", I18N_NOOP2("OSM::amenity/shop", "Music") },
     { "musical_instrument", I18N_NOOP2("OSM::amenity/shop", "Musical Instruments") },
@@ -117,6 +119,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "recycling", I18N_NOOP2("OSM::amenity/shop", "Recycling") },
     { "restaurant", I18N_NOOP2("OSM::amenity/shop", "Restaurant") },
     { "school", I18N_NOOP2("OSM::amenity/shop", "School") },
+    { "scooter_rental", I18N_NOOP2("OSM::amenity/shop", "Kick Scooter Rental") },
     { "seafood", I18N_NOOP2("OSM::amenity/shop", "Seafood") },
     { "shoes", I18N_NOOP2("OSM::amenity/shop", "Shoes") },
     { "shop", I18N_NOOP2("OSM::amenity/shop", "Shop") },
